@@ -1,37 +1,20 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Platforms\Keywords;
 
-use Doctrine\Deprecations\Deprecation;
-
 /**
- * Microsoft SQL Server 2012 reserved keyword dictionary.
  * Reserved keywords list corresponding to the Microsoft SQL Server database platform of the oldest supported version.
  */
 class SQLServerKeywords extends KeywordList
 {
     /**
-     * {@inheritdoc}
-     *
-     * @deprecated
-     */
-    public function getName()
-    {
-        Deprecation::triggerIfCalledFromOutside(
-            'doctrine/dbal',
-            'https://github.com/doctrine/dbal/pull/5433',
-            'SQLServerKeywords::getName() is deprecated.',
-        );
-
-        return 'SQLServer';
-    }
-
-    /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      *
      * @link http://msdn.microsoft.com/en-us/library/aa238507%28v=sql.80%29.aspx
      */
-    protected function getKeywords()
+    protected function getKeywords(): array
     {
         return [
             'ADD',
